@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
 // Copyright 2008-2016 National ICT Australia (NICTA)
 // 
@@ -19,6 +21,22 @@
 
 
 
+template<typename T1>
+arma_warn_unused
+inline
+typename enable_if2< is_real<typename T1::pod_type>::value, const Op<T1, op_pinv_default> >::result
+pinv
+  (
+  const Base<typename T1::elem_type,T1>& X
+  )
+  {
+  arma_extra_debug_sigprint();
+  
+  return Op<T1, op_pinv_default>(X.get_ref());
+  }
+
+
+
 template<typename T1>
 arma_warn_unused
 inline
@@ -26,7 +44,7 @@ typename enable_if2< is_real<typename T1::pod_type>::value, const Op<T1, op_pinv
 pinv
   (
   const Base<typename T1::elem_type,T1>& X,
-  const typename T1::pod_type            tol    = 0.0,
+  const typename T1::pod_type            tol,
   const char*                            method = nullptr
   )
   {
