@@ -1,3 +1,5 @@
+// SPDX-License-Identifier: Apache-2.0
+// 
 // Copyright 2011-2017 Ryan Curtin (http://www.ratml.org/)
 // Copyright 2017 National ICT Australia (NICTA)
 //
@@ -54,7 +56,7 @@ TEST_CASE("fn_spsolve_sparse_test")
       {
       for (uword j = 0; j < dX.n_rows; ++j)
         {
-        REQUIRE( (double) X(j, i) == Approx((double) dX(j, i)).epsilon(0.01) );
+        REQUIRE( (double) X(j, i) == Approx((double) dX(j, i)).margin(0.01) );
         }
       }
     }
@@ -94,7 +96,7 @@ TEST_CASE("fn_spsolve_sparse_nonsymmetric_test")
       {
       for (uword j = 0; j < dX.n_rows; ++j)
         {
-        REQUIRE( (double) X(j, i) == Approx((double) dX(j, i)).epsilon(0.01) );
+        REQUIRE( (double) X(j, i) == Approx((double) dX(j, i)).margin(0.01) );
         }
       }
     }
@@ -135,7 +137,7 @@ TEST_CASE("fn_spsolve_sparse_float_test")
       {
       for (size_t j = 0; j < dX.n_rows; ++j)
         {
-        REQUIRE( (float) X(j, i) == Approx((float) dX(j, i)).epsilon(0.01) );
+        REQUIRE( (float) X(j, i) == Approx((float) dX(j, i)).margin(0.01) );
         }
       }
     }
@@ -175,7 +177,7 @@ TEST_CASE("fn_spsolve_sparse_nonsymmetric_float_test")
       {
       for (uword j = 0; j < dX.n_rows; ++j)
         {
-        REQUIRE( (float) X(j, i) == Approx((float) dX(j, i)).epsilon(0.01) );
+        REQUIRE( (float) X(j, i) == Approx((float) dX(j, i)).margin(0.01) );
         }
       }
     }
@@ -217,7 +219,7 @@ TEST_CASE("fn_spsolve_sparse_complex_float_test")
       for (uword j = 0; j < dX.n_rows; ++j)
         {
         REQUIRE( (float) std::abs((cx_float) X(j, i)) ==
-                 Approx((float) std::abs((cx_float) dX(j, i))).epsilon(0.01) );
+                 Approx((float) std::abs((cx_float) dX(j, i))).margin(0.01) );
         }
       }
     }
@@ -258,7 +260,7 @@ TEST_CASE("fn_spsolve_sparse_nonsymmetric_complex_float_test")
       for (uword j = 0; j < dX.n_rows; ++j)
         {
         REQUIRE( (float) std::abs((cx_float) X(j, i)) ==
-                 Approx((float) std::abs((cx_float) dX(j, i))).epsilon(0.01) );
+                 Approx((float) std::abs((cx_float) dX(j, i))).margin(0.01) );
         }
       }
     }
@@ -300,7 +302,7 @@ TEST_CASE("fn_spsolve_sparse_complex_test")
       for (uword j = 0; j < dX.n_rows; ++j)
         {
         REQUIRE( (double) std::abs((cx_double) X(j, i)) ==
-                 Approx((double) std::abs((cx_double) dX(j, i))).epsilon(0.01) );
+                 Approx((double) std::abs((cx_double) dX(j, i))).margin(0.01) );
         }
       }
     }
@@ -341,7 +343,7 @@ TEST_CASE("fn_spsolve_sparse_nonsymmetric_complex_test")
       for (uword j = 0; j < dX.n_rows; ++j)
         {
         REQUIRE( (double) std::abs((cx_double) X(j, i)) ==
-                 Approx((double) std::abs((cx_double) dX(j, i))).epsilon(0.01) );
+                 Approx((double) std::abs((cx_double) dX(j, i))).margin(0.01) );
         }
       }
     }
@@ -376,7 +378,7 @@ TEST_CASE("fn_spsolve_delayed_sparse_test")
     {
     for (uword j = 0; j < dX.n_rows; ++j)
       {
-      REQUIRE( (double) X(j, i) == Approx((double) dX(j, i)).epsilon(0.01) );
+      REQUIRE( (double) X(j, i) == Approx((double) dX(j, i)).margin(0.01) );
       }
     }
   }
@@ -420,7 +422,7 @@ TEST_CASE("fn_spsolve_superlu_solve_test")
     {
     for (uword j = 0; j < x.n_rows; ++j)
       {
-      REQUIRE( (double) x(j, i) == Approx(dx(j, i)).epsilon(0.01) );
+      REQUIRE( (double) x(j, i) == Approx(dx(j, i)).margin(0.01) );
       }
     }
   }
@@ -451,7 +453,7 @@ TEST_CASE("fn_spsolve_random_superlu_solve_test")
       {
       for (uword j = 0; j < x.n_rows; ++j)
         {
-        REQUIRE( x(j, i) == Approx((double) trueX(j, i)).epsilon(0.01) );
+        REQUIRE( x(j, i) == Approx((double) trueX(j, i)).margin(0.01) );
         }
       }
     }
@@ -496,7 +498,7 @@ TEST_CASE("fn_spsolve_float_superlu_solve_test")
     {
     for (uword j = 0; j < x.n_rows; ++j)
       {
-      REQUIRE( (float) x(j, i) == Approx(dx(j, i)).epsilon(0.01) );
+      REQUIRE( (float) x(j, i) == Approx(dx(j, i)).margin(0.01) );
       }
     }
   }
@@ -530,7 +532,7 @@ TEST_CASE("fn_spsolve_float_random_superlu_solve_test")
         if (std::abs(trueX(j, i)) < 0.001)
           REQUIRE( std::abs(x(j, i)) < 0.005 );
         else
-          REQUIRE( trueX(j, i) == Approx((float) x(j, i)).epsilon(0.01) );
+          REQUIRE( trueX(j, i) == Approx((float) x(j, i)).margin(0.01) );
         }
       }
     }
@@ -582,9 +584,9 @@ TEST_CASE("fn_spsolve_cx_float_superlu_solve_test")
       else
         {
         REQUIRE( ((cx_float) x(j, i)).real() ==
-                 Approx(dx(j, i).real()).epsilon(0.01) );
+                 Approx(dx(j, i).real()).margin(0.01) );
         REQUIRE( ((cx_float) x(j, i)).imag() ==
-                 Approx(dx(j, i).imag()).epsilon(0.01) );
+                 Approx(dx(j, i).imag()).margin(0.01) );
         }
       }
     }
@@ -623,9 +625,9 @@ TEST_CASE("fn_spsolve_cx_float_random_superlu_solve_test")
         else
           {
           REQUIRE( ((cx_float) trueX(j, i)).real() ==
-                   Approx(x(j, i).real()).epsilon(0.01) );
+                   Approx(x(j, i).real()).margin(0.01) );
           REQUIRE( ((cx_float) trueX(j, i)).imag() ==
-                   Approx(x(j, i).imag()).epsilon(0.01) );
+                   Approx(x(j, i).imag()).margin(0.01) );
           }
         }
       }
@@ -678,9 +680,9 @@ TEST_CASE("fn_spsolve_cx_superlu_solve_test")
       else
         {
         REQUIRE( ((cx_double) x(j, i)).real() ==
-                 Approx(dx(j, i).real()).epsilon(0.01) );
+                 Approx(dx(j, i).real()).margin(0.01) );
         REQUIRE( ((cx_double) x(j, i)).imag() ==
-                 Approx(dx(j, i).imag()).epsilon(0.01) );
+                 Approx(dx(j, i).imag()).margin(0.01) );
         }
       }
     }
@@ -719,9 +721,9 @@ TEST_CASE("fn_spsolve_cx_random_superlu_solve_test")
         else
           {
           REQUIRE( ((cx_double) trueX(j, i)).real() ==
-                   Approx(x(j, i).real()).epsilon(0.01) );
+                   Approx(x(j, i).real()).margin(0.01) );
           REQUIRE( ((cx_double) trueX(j, i)).imag() ==
-                   Approx(x(j, i).imag()).epsilon(0.01) );
+                   Approx(x(j, i).imag()).margin(0.01) );
           }
         }
       }
@@ -754,7 +756,7 @@ TEST_CASE("fn_spsolve_function_test")
     {
     for (uword j = 0; j < x.n_rows; ++j)
       {
-      REQUIRE( (double) trueX(j, i) == Approx(x(j, i)).epsilon(0.01) );
+      REQUIRE( (double) trueX(j, i) == Approx(x(j, i)).margin(0.01) );
       }
     }
   }
@@ -791,7 +793,7 @@ TEST_CASE("fn_spsolve_float_function_test")
         }
       else
         {
-        REQUIRE( (float) trueX(j, i) == Approx(x(j, i)).epsilon(0.01) );
+        REQUIRE( (float) trueX(j, i) == Approx(x(j, i)).margin(0.01) );
         }
       }
     }
@@ -830,9 +832,9 @@ TEST_CASE("fn_spsolve_cx_function_test")
       else
         {
         REQUIRE( ((cx_double) trueX(j, i)).real() ==
-                 Approx(x(j, i).real()).epsilon(0.01) );
+                 Approx(x(j, i).real()).margin(0.01) );
         REQUIRE( ((cx_double) trueX(j, i)).imag() ==
-                 Approx(x(j, i).imag()).epsilon(0.01) );
+                 Approx(x(j, i).imag()).margin(0.01) );
         }
       }
     }
@@ -871,9 +873,9 @@ TEST_CASE("fn_spsolve_cx_float_function_test")
       else
         {
         REQUIRE( ((cx_float) trueX(j, i)).real() ==
-                 Approx(x(j, i).real()).epsilon(0.01) );
+                 Approx(x(j, i).real()).margin(0.01) );
         REQUIRE( ((cx_float) trueX(j, i)).imag() ==
-                 Approx(x(j, i).imag()).epsilon(0.01) );
+                 Approx(x(j, i).imag()).margin(0.01) );
         }
       }
     }
